% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/derekovecs.R
\name{collocationScores}
\alias{collocationScores}
\title{Get collocation scores}
\usage{
collocationScores(w, c, ...)
}
\arguments{
\item{w}{The target word/node.}

\item{c}{The collocate.}

\item{...}{Additional parameters to pass to the API.}
}
\value{
A one row data frame with collocate and its association scores.
\describe{
\item{word}{collocate}
\item{f2}{abs. frequency of collocate}
\item{f}{abs. frequency of collocation}
\item{npmi}{normalized pmi (Bouma 2009)}
\item{pmi}{pointwise mutual information}
\item{dice}{dice score}
\item{ld}{log-dice score (Rychlý 2008) for whole window}
\item{lfmd}{log-frequency biased mutual dependency ≙ pmi³ (Dalle 1994; Thanopoulos et al. 2002)}
\item{llr}{log-likelihood (Dunning 1993; Evert 2004)}
\item{ln_count}{frequency of collocate as left neighbour of node}
\item{ln_pmi}{pmi as left neighbour}
\item{md}{mutual dependency ≙ pmi² (Dalle 1994; Thanopoulos et al. 2002)}
\item{rn_count}{frequency of collocate as right neighbour of node}
\item{rn_pmi}{pmi as right neighbour}
\item{ldaf}{log-dice score for auto focus window}
\item{win}{binary encoded positions at which the collocate  appears at least once, e.g.: 1023 = 2^10-1 ≙ 11111 node 11111}
\item{afwin}{binary encoded auto-focus window (see Perkuhn et al. 2012: E8-15), e.g. 64 = 2^6 ≙ 00010 node 00000 (Aus gutem Grund)}
}
}
\description{
Calculate the association scores between a node (target word) and words in a window around the it.
}
\references{
Daille, B. (1994): Approche mixte pour l’extraction automatique de terminologie: statistiques lexicales et filtres linguistiques. PhD thesis, Université Paris 7.

Dunning, T. (1993): Accurate methods for the statistics of surprise and coincidence. Comput. Linguist. 19, 1 (March 1993), 61-74.

Evert, Stefan (2004): The Statistics of Word Cooccurrences: Word Pairs and Collocations. PhD dissertation, IMS, University of Stuttgart. Published in 2005, URN urn:nbn:de:bsz:93-opus-23714.
Free PDF available from \url{https://purl.org/stefan.evert/PUB/Evert2004phd.pdf}

Thanopoulos, A., Fakotakis, N., Kokkinakis, G. (2002): Comparative evaluation of collocation extraction metrics. In: Proc. of LREC 2002: 620–625.
}
